@@ -1,10 +1,10 @@
-__version__ = "0.6.4"
+__version__ = "0.6.5"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
 __git_branch__ = '(Not currently on any branch)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '4dd2df34f70853a3a1320db061f7897f24341f95'
-__git_head_subject__ = 'Finished release v0.6.4.'
+__git_head_hash__ = '369d383f5bdc2bf69433a9dfce3c45c2e2a5a900'
+__git_head_subject__ = 'HOSTDEV-1110 reset lesser version numbers when releasing minor/major'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
